@@ -138,12 +138,6 @@ class APIConnection : public APIServerConnection {
   void on_timeout_(uint32_t time);
   void on_data_(uint8_t *buf, size_t len);
   void parse_recv_buffer_();
-  void set_nodelay(bool nodelay) override {
-    if (nodelay == this->current_nodelay_)
-      return;
-    this->client_->setNoDelay(nodelay);
-    this->current_nodelay_ = nodelay;
-  }
 
   enum class ConnectionState {
     WAITING_FOR_HELLO,
