@@ -1,2 +1,2 @@
 # Dummy package to allow components to depend on network
-CODEOWNERS = ['@esphome/core']
+CODEOWNERS = ["@esphome/core"]
