@@ -6,7 +6,13 @@
 namespace esphome {
 namespace remote_transmitter {
 
-class RemoteTransmitterComponent : public remote_base::RemoteTransmitterBase, public Component {
+class RemoteTransmitterComponent : public remote_base::RemoteTransmitterBase,
+                                   public Component
+#ifdef ARDUINO_ARCH_ESP32
+    ,
+                                   public remote_base::RemoteRMTChannel
+#endif
+{
  public:
   explicit RemoteTransmitterComponent(GPIOPin *pin) : remote_base::RemoteTransmitterBase(pin) {}
 
@@ -34,6 +40,7 @@ class RemoteTransmitterComponent : public remote_base::RemoteTransmitterBase, pu
   uint32_t current_carrier_frequency_{UINT32_MAX};
   bool initialized_{false};
   std::vector<rmt_item32_t> rmt_temp_;
+  esp_err_t error_code_{ESP_OK};
 #endif
   uint8_t carrier_duty_percent_{50};
 };
